process KMERCLUST_LOAD {
    tag "$specie"
    label 'big_mem_mono_cpus'

    container "lbmc/kmerclust:0.0.6"
    publishDir "results/${params.kmer_size}/${specie}/", mode: 'copy'

    input:
    tuple val(specie), path(csv)
    path params_csv

    output:
    tuple val(specie), path("*.Rdata"), emit: rdata 
    path "versions.yml"           , emit: versions

    script:
    def args = task.ext.args ?: ''
    """
    Rscript ${projectDir}/bin/kmerclust_load.R ${params_csv} ${csv} ${specie}

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        Rkmerclust: 0.0.6 
    END_VERSIONS
    """
}

process KMERCLUST_BOOT {
    tag "$specie"
    label 'big_mem_multi_cpus'

    container "lbmc/kmerclust:0.0.6"
    publishDir "results/${params.kmer_size}/${specie}/", mode: 'copy'

    input:
    tuple val(id), val(specie), path(rdata)

    output:
    tuple val(specie), path("*.Rdata"), emit: rdata 
    path "versions.yml"           , emit: versions

    script:
    def args = task.ext.args ?: ''
    """
    Rscript ${projectDir}/bin/kmerclust_boot.R ${specie} ${task.cpus} ${id}

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        Rkmerclust: 0.0.6 
    END_VERSIONS
    """
}

process KMERCLUST {
    tag "$specie"
    label 'big_mem_multi_cpus'

    container "lbmc/kmerclust:0.0.6"
    publishDir "results/${params.kmer_size}/${specie}/", mode: 'copy'

    input:
    tuple val(id), val(specie), path(rdata)

    output:
    tuple val(specie), path("*.Rdata"), emit: rdata 
    path "versions.yml"           , emit: versions

    script:
    def args = task.ext.args ?: ''
    """
    Rscript ${projectDir}/bin/kmerclust.R ${specie} ${task.cpus}

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        Rkmerclust: 0.0.6 
    END_VERSIONS
    """
}

process KMERCLUST_MERGE {
    tag "$specie"
    label 'big_mem_mono_cpus'

    container "lbmc/kmerclust:0.0.6"
    publishDir "results/${params.kmer_size}/${specie}/", mode: 'copy'

    input:
    tuple val(specie), path(rdata)

    output:
    tuple val(specie), path("*.Rdata"), emit: rdata 
    path "versions.yml"           , emit: versions

    script:
    def args = task.ext.args ?: ''
    """
    Rscript ${projectDir}/bin/kmerclust_merge.R ${specie}

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        Rkmerclust: 0.0.6 
    END_VERSIONS
    """
}

process KMERCLUST_PLOT {
    tag "$specie"
    label 'big_mem_mono_cpus'

    container "lbmc/kmerclust:0.0.6"
    publishDir "results/${params.kmer_size}/${specie}/", mode: 'copy'

    input:
    tuple val(specie), path(rdata)

    output:
    tuple val(specie), path("*.pdf"), emit: pdf 
    path "versions.yml"           , emit: versions

    script:
    def args = task.ext.args ?: ''
    """
    Rscript ${projectDir}/bin/kmerclust_plot.R ${specie}

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        Rkmerclust: 0.0.6 
    END_VERSIONS
    """
}
